@@ -1,7 +1,7 @@
 <?php
 	/*
 	MGB 0.6.x - OpenSource PHP and MySql Guestbook
-	Copyright (C) 2004 - 2007 Juergen Grueneisl - http://www.m-gb.org/
+	Copyright (C) 2004 - 2011 Juergen Grueneisl - http://www.m-gb.org/
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -52,10 +52,10 @@
 
 	// checks if email is valid
 	if (!function_exists("check_mail"))
-		{		
+		{
 		function check_mail($email)
 			{
-			if (eregi("^[a-z0-9]+([-_\.]?[a-z0-9])+@[a-z0-9]+([-_\.]?[a-z0-9])+\.[a-z]{2,4}", $email))
+			if (preg_match("/^[a-z0-9]+([-_\.]?[a-z0-9])+@[a-z0-9]+([-_\.]?[a-z0-9])+\.[a-z]{2,4}/", $email))
 				{
 				return TRUE;
 				}
@@ -69,7 +69,7 @@
 
 	// checks if icq number is valid
 	if (!function_exists("check_number"))
-		{		
+		{
 		function check_number($number)
 			{
 			if (preg_match("=^[0-9]+$=i", $number))
@@ -356,7 +356,7 @@
 				$ok = 1;
 				}
 
-			$sql = "SELECT user_email FROM ".$db['prefix']."user WHERE user_email=".$email;		
+			$sql = "SELECT user_email FROM ".$db['prefix']."user WHERE user_email=".$email;
 			$result = @mysql_query($sql, $link) or die ("(functions.inc.php, check_if_user_exists) Error, line 360: ".mysql_error());
 			
 			$user = @mysql_fetch_array($result);
@@ -475,38 +475,77 @@
 	// generate captcha
 	if (!function_exists("generate_captcha"))
 		{
-		function generate_captcha()
+		function generate_captcha($captcha_method)
 			{
 			require "includes/config.inc.php";
-
-			$captcha_letters = array("A", "B", "C", "D", "E", "F", "G", "H", "J", "K", "L", "M", "N", "O", "P", "Q", "R", "S", "T", "U", "V", "W", "X", "Y", "Z");
-			$captcha_numbers = array("2", "3", "4", "5", "6", "8", "9");
-			$captcha_special = array("!", "?");
-
-			for ($i = 0, $code = NULL; strlen($code) < 6; $i++)
+			if ($captcha_method == 0)
 				{
-				// if you like to use special characters in your captcha
-				// set the "2" in the following line to "3"
-				$captcha_random = rand(1, 2);
-				if ($captcha_random == 1)
+				$captcha_letters = array("A", "B", "C", "D", "E", "F", "G", "H", "J", "K", "L", "M", "N", "O", "P", "Q", "R", "S", "T", "U", "V", "W", "X", "Y", "Z");
+				$captcha_numbers = array("2", "3", "4", "5", "6", "8", "9");
+				$captcha_special = array("!", "?");
+				for ($i = 0, $code = NULL; strlen($code) < 6; $i++)
 					{
-					$code .= $captcha_letters[rand(0, (count($captcha_letters))-1)];
+					// if you like to use special characters in your captcha
+					// set the "2" in the following line to "3"
+					$captcha_random = rand(1, 2);
+					if ($captcha_random == 1)
+						{
+						$code .= $captcha_letters[rand(0, (count($captcha_letters))-1)];
+						}
+					elseif ($captcha_random == 2)
+						{
+						$code .= $captcha_numbers[rand(0, (count($captcha_numbers))-1)];
+						}
+					else
+						{
+						$code .= $captcha_special[rand(0, (count($captcha_special))-1)];
+						}
 					}
-				elseif ($captcha_random == 2)
+				$sql = "UPDATE `".$db['prefix']."captcha` SET `code` = '".$code."' LIMIT 1";
+				}
+			elseif ($captcha_method == 1)
+				{
+				$captcha_rnd_1 = rand(1, 10);
+				$captcha_rnd_2 = rand(1, 20);
+				$captcha_rnd_3 = rand(1, 30);
+
+				$captcha_rnd_method = rand(1, 2);
+				if ($captcha_rnd_method == 1)
 					{
-					$code .= $captcha_numbers[rand(0, (count($captcha_numbers))-1)];
+					$captcha_sum = $captcha_rnd_1 + $captcha_rnd_2;
+					$captcha_math_symbol_1 = "+";
 					}
 				else
 					{
-					$code .= $captcha_special[rand(0, (count($captcha_special))-1)];
+					$captcha_sum = $captcha_rnd_1 - $captcha_rnd_2;
+					$captcha_math_symbol_1 = "-";
 					}
+				$captcha_sum2 = $captcha_sum; // debug
+
+				$captcha_rnd_method = rand(1, 2);
+				if ($captcha_rnd_method == 1)
+					{
+					$captcha_sum = $captcha_sum + $captcha_rnd_3;
+					$captcha_math_symbol_2 = "+";
+					}
+				else
+					{
+					$captcha_sum = $captcha_sum - $captcha_rnd_3;
+					$captcha_math_symbol_2 = "-";
+					}
+
+				// generate formula for user
+				$captcha_math = $captcha_rnd_1.$captcha_math_symbol_1.$captcha_rnd_2.$captcha_math_symbol_2.$captcha_rnd_3;
+
+				$sql = "UPDATE `".$db['prefix']."captcha_math` SET `math` = '".$captcha_math."', `sum` = '".$captcha_sum."' LIMIT 1 ;";
 				}
 
-			// save captcha to database
-			$sql = "UPDATE `".$db['prefix']."captcha` SET `code` = '$code' LIMIT 1";
-			$link = @mysql_connect($db['hostname'], $db['username'], $db['password']) or die ("(functions.inc.php, generate_captcha) Error, line 507: ".mysql_error());
-			@mysql_select_db($db['dbname'], $link) or die ("(functions.inc.php, generate_captcha) Error, line 508: ".mysql_error());
-			@mysql_query($sql, $link) or die ("(functions.inc.php, generate_captcha) Error, line 509: ".mysql_error());
+			if (isset ($captcha_method))
+				{
+				$link = @mysql_connect($db['hostname'], $db['username'], $db['password']) or die ("(functions.inc.php, generate_captcha) Error, line 548: ".mysql_error());
+				@mysql_select_db($db['dbname'], $link) or die ("(functions.inc.php, generate_captcha) Error, line 549: ".mysql_error());
+				@mysql_query($sql, $link) or die ("(functions.inc.php, generate_captcha) Error, line 550: ".mysql_error());
+				}
 			}
 		}
 
@@ -601,7 +640,7 @@
 			{
 			require "../includes/config.inc.php";
 			
-			$sql = "SELECT user_level, r_settings, r_activate, r_deactivate, r_delete, r_edit FROM ".$db['prefix']."user WHERE ID=".$sessid;
+			$sql = "SELECT user_level, r_settings, r_activate, r_deactivate, r_delete, r_edit, r_spam FROM ".$db['prefix']."user WHERE ID=".$sessid;
 			$link = @mysql_connect($db['hostname'], $db['username'], $db['password']) or die ("(functions.inc.php, check_rights) Error, line 605: ".mysql_error());
 			@mysql_select_db($db['dbname'], $link) or die ("(functions.inc.php, check_rights) Error, line 606: ".mysql_error());
 			$result = @mysql_query($sql, $link) or die ("(functions.inc.php, check_rights) Error, line 607: ".mysql_error());
@@ -634,6 +673,10 @@
 						{
 						return TRUE;
 						}
+					elseif($site == "spam" AND $user['r_spam'] == 1)
+						{
+						return TRUE;
+						}
 					elseif($site == "version")
 						{
 						return TRUE;
@@ -660,4 +703,19 @@
 			return $string;
 			}
 		}
+
+	// get version info with cURL
+	if (!function_exists("get_mgb_version_info"))
+		{
+		function get_mgb_version_info($url)
+			{
+			$ch = curl_init($url);
+			curl_setopt ($ch, CURLOPT_URL, $url);
+			curl_setopt ($ch, CURLOPT_HEADER, 0);
+			curl_setopt ($ch, CURLOPT_RETURNTRANSFER, 1);
+			$result = curl_exec ($ch);
+			curl_close ($ch);
+			return $result;
+			}
+		}
 ?>
