@@ -19,7 +19,7 @@
 	*/
 
 	// ============================ //
-	// lang_admin.php - Italian 1.0 //
+	// lang_admin.php - Italian 1.1 //
 	// ============================ //
 	//
 	// This language file was translated by Christian Castelli alias VooDoo (voodoo81people@gmail.com) 
@@ -67,11 +67,13 @@
 	// general strings
 	$lang['back_to_mainpage'] = "Torna alla pagina principale";
 	$lang['back'] = "Indietro";
+	$lang['go'] = "Go!";
 	$lang['entry'] = "Post";
 	$lang['entries'] = "Post";
 	$lang['no_entries'] = "Non ci sono post disponibili.";
 	$lang['no_deactivated_entries'] = "Non ci sono post diattivati.";
 	$lang['no_activated_entries'] = "Non ci sono post attivati";
+	$lang['no_spam_entries'] = "No spam entries available.";
 	$lang['entries_on_pages'] = "Post in {PAGES} pagine";
 	$lang['page_first'] = "First page";
 	$lang['page_first_symbol'] = "&laquo;";
@@ -86,9 +88,21 @@
 	$lang['activate_entry'] = "Attiva questo post";
 	$lang['deactivate_entry'] = "Disattiva questo post";
 	$lang['delete_entry'] = "Cancella questo post";
+	$lang['mark_as_spam'] = "Mark as spam";
+	$lang['nospam_entry'] = "Mark entry as 'no spam' and activate it";
+	$lang['nospam_deactivate_entry'] = "Mark entry as 'no spam' but let it deactivated";
 	$lang['active'] = "Questo post è stato attivato nel guestbook";
 	$lang['inactive'] = "Questo post non è stato attivato nel guestbook";
 	$lang['edit_entry'] = "Edita il post";
+	$lang['do_nothing'] = "Do nothing ...";
+	$lang['delete_whole_spam'] = "Delete all spam entries";
+	$lang['mark_all_no_spam_deactivate'] = "Mark all entries as 'no spam' and activate it";
+	$lang['mark_all_no_spam_activate'] = "Mark all entries as 'no spam' but let them deactivated";
+	$lang['mark_all_as_spam'] = "Mark all entries as spam";
+	$lang['activate_all_entries'] = "Activate all entries";
+	$lang['deactivate_all_entries'] = "Deactivate all entries";
+	$lang['delete_all_entries'] = "Delete all entries";
+
 	$lang['sendmail_user_notification_title'] = "Il tuo post presso {DOMAIN} e\' stato attivato";
 	$lang['sendmail_user_comment_title'] = "al tuo post presso {DOMAIN} è stato fatto un commento";
 	$lang['sendmail_adduser_title'] = "I tuoi dati utenti presso {DOMAIN}";
@@ -109,7 +123,9 @@
 	$lang['deactivate'] = "Disattiva il post";
 	$lang['delete'] = "Cancella il post";
 	$lang['edit'] = "Modifica il post";
+	$lang['spam'] = "Spam entries";
 	$lang['users'] = "Amministrazione utenti";
+	$lang['stats'] = "Statistics";
 	$lang['license'] = "Licenza";
 	$lang['forum'] = "Forum";
 	$lang['bugreport'] = "Riporta un bug";
@@ -117,14 +133,13 @@
 	$lang['manual'] = "Documentazione";
 	$lang['paypal'] = "Se ti piace MGB e pensi sia utile, puoi considerare di effettuare una donazione per supportare il suo sviluppo futuro.";
 
-	// settings.php
+	// settings.inc.php
 	$lang['edit_caption_general'] = "Settaggi generali";
 	$lang['edit_caption_look'] = "Look &amp; feel";
 	$lang['edit_caption_gravatars'] = "Supporto gravatar";
 	$lang['edit_caption_security'] = "Sicurezza";
 	$lang['edit_caption_email'] = "eMail";
 	$lang['edit_save_message'] = "Saved settings successfull.";
-
 	$lang['edit_title'] = "Titolo:";
 	$lang['edit_h_author'] = "Autore:";
 	$lang['edit_h_domain'] = "Dominio:";
@@ -152,6 +167,7 @@
 	$lang['edit_captcha_method'] = "Sort of captcha:";
 	$lang['edit_akismet_plugin'] = "Akismet-Plugin:";
 	$lang['edit_akismet_api'] = "Akismet API Key:";
+	$lang['edit_akismet_mark_as_spam'] = "Spam marking:";
 	$lang['edit_user_notification'] = "Notifica utente:";
 	$lang['edit_user_show_email'] = "Usermail presso il guestbook:";
 	$lang['edit_session_timeout'] = "timeout della sesseione:";
@@ -194,6 +210,7 @@
 	$lang['edit_expl_akismet_api'] = "In order to use Akismet you need an <a href='http://akismet.com/signup/#free' title='Akismet API Key'>API Key</a>. Sign in for free and enter it here after registration.";
 	$lang['edit_expl_akismet_check_ok'] = "<span class='same_version'>Akismet is installed!</span>";
 	$lang['edit_expl_akismet_check_fail'] = "<span class='old_version'>Akismet is NOT installed!</span>";
+	$lang['edit_expl_akismet_mark_as_spam'] = "If this option is enabled, positive Akismet entries are marked as spam and appear in the administration panel so you can check them for yourself and decide what to do with.";
 	$lang['edit_expl_user_notification'] = "Permette all'utente di decidere se sarà avvertito via email se il suo post sarà attivato.";
 	$lang['edit_expl_user_show_email'] = "Permette all'utente di decidere se il suo indirizzo eMail verrà mostrato nel guestbook oppure no. Se disabilita la checkbox nessuno all'infuori dell'amministratore potrà spedirgli una mail.";
 	$lang['edit_expl_session_timeout'] = "Un ut3ente inattivo verrà automaticamente sloggato se questo periodo scade. Espresso in <b>secondi</b>. Il valore dev'essere maggiore o uguale a (>=) <b>60</b>.";
@@ -232,6 +249,7 @@
 	$lang['r_deactivate'] = "Disattiva i post:";
 	$lang['r_delete'] = "Cancella i post:";
 	$lang['r_edit'] = "Modifica i post:";
+	$lang['r_spam'] = "Manage spam:";
 	$lang['old_password'] = "La tua password corrente:";
 	$lang['new_password_1'] = "Nuova password:";
 	$lang['new_password_2'] = "Digita di nuovo:";
@@ -249,13 +267,14 @@
 	$lang['current_version'] = "versione installata:";
 	$lang['stable_version'] = "ultima versione stabile:";
 	$lang['unstable_version'] = "ultima versione instabile:";
-	$lang['old_version'] = "La tua versione è vecchia.<br>Si raccomanda un aggiornamento.<br><br><a href='http://www.m-gb.org/index.php?kat=5' class='admin' target='_blank' title='Update now'>Vai alla nuova versione</a>";
+	$lang['old_version'] = "La tua versione è vecchia.<br>Si raccomanda un aggiornamento.<br><br><a href='http://www.m-gb.org/index.php?id=download_gb' class='admin' target='_blank' title='Update now'>Vai alla nuova versione</a>";
 	$lang['same_version'] = "Stai usando l'ultima versione disponibile.<br>Non si necessita di un aggiornamento.";
 	$lang['newer_version'] = "La tua versione è più recente dell'ultima versione stabile.<br>Non si necessita di un aggiornamento.";
+	$lang['new_version_available'] = "A new version is available: <a href='http://www.m-gb.org/files/latest/mgb-latest.zip' class='admin' target='_blank' title='Upgrade now!'>{LATEST_VERSION}</a>";
 
 	// lostpassword.php
 	$lang['lostpassword_mail'] = "il tuo indirizzo eMail:";
 	$lang['get_new_pw'] = "richiedi una nuova password";
 	$lang['lostpassword_success'] = "La tua richiesta è terminata. Riceverai a breve una eMail<br>con un link di conferma. cliccaci sopra per attivare la tua nuova password.";
 	$lang['lostpassword_success_created'] = "I tuoi nuovi dati di login sono stati<br>spediti via eMail.";
-?>
\ No newline at end of file
+?>
