@@ -1,7 +1,7 @@
 <?php
 	/*
 	MGB 0.6.x - OpenSource PHP and MySql Guestbook
-	Copyright (C) 2004 - 2007 Juergen Grueneisl - http://www.m-gb.org/
+	Copyright (C) 2004 - 2011 Juergen Grueneisl - http://www.m-gb.org/
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@
 	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 	*/
 
-	// ================ //
-	// mysql.php - 0.2  //
-	// ================ //
+	// =============== //
+	// mysql.php - 0.4 //
+	// =============== //
 	//
 	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //
 
@@ -55,14 +55,28 @@
 	$sql = array();
 
 	$sql[1] = "CREATE TABLE ".$db_prefix."captcha (
-		  `code` VARCHAR( 11 ) NOT NULL,
+		  `code` VARCHAR( 11 ) NOT NULL ,
 		  PRIMARY KEY ( `code` )
-		  ) TYPE = MYISAM ;";
+		  ) TYPE = MYISAM;";
 
-	$sql[2] = "INSERT INTO ".$db_prefix."captcha ( `code` ) VALUES ( 'A B C D E F' );";
+	$sql[2] = "INSERT INTO ".$db_prefix."captcha ( `code` ) VALUES ( 'ABCDEF' );";
 
-	$sql[3] = "CREATE TABLE ".$db_prefix."entries (
-		  `ID` INT( 10 ) NOT NULL AUTO_INCREMENT PRIMARY KEY ,
+	$sql[3] = "CREATE TABLE ".$db_prefix."captcha_math (
+		  `math` VARCHAR( 20 ) NOT NULL ,
+		  `sum` INT NOT NULL ,
+		  PRIMARY KEY ( `math` )
+		  ) TYPE = MYISAM;";
+
+	$sql[4] = "INSERT INTO ".$db_prefix."captcha_math (
+			`math` ,
+			`sum`
+		) VALUES (
+			'1+2+3' ,
+			'6'
+			);";
+
+	$sql[5] = "CREATE TABLE ".$db_prefix."entries (
+		  `ID` INT NOT NULL AUTO_INCREMENT PRIMARY KEY ,
 		  `name` VARCHAR( 255 ) NOT NULL ,
 		  `city` VARCHAR( 255 ) NOT NULL ,
 		  `email` VARCHAR( 255 ) NOT NULL ,
@@ -76,18 +90,19 @@
 		  `timestamp` VARCHAR( 255 ) NOT NULL ,
 		  `user_notification` TINYINT( 1 ) NOT NULL ,
 		  `user_show_email` TINYINT( 1 ) NOT NULL ,
-		  `checked` TINYINT( 1 ) NOT NULL
-		  ) TYPE = MYISAM ;";
+		  `checked` TINYINT( 1 ) NOT NULL ,
+		  `isspam` TINYINT( 1 ) NOT NULL
+		  ) TYPE = MYISAM;";
 
 
-	$sql[4] = "CREATE TABLE ".$db_prefix."lastip (
+	$sql[6] = "CREATE TABLE ".$db_prefix."lastip (
 		  `lastIP` VARCHAR( 15 ) NOT NULL ,
 		  PRIMARY KEY ( `lastIP` )
-		  ) TYPE = MYISAM ;";
+		  ) TYPE = MYISAM;";
 
 
-	$sql[5] = "CREATE TABLE ".$db_prefix."settings (
-		  `title` VARCHAR(255) NOT NULL DEFAULT 'MGB 0.6',
+	$sql[7] = "CREATE TABLE ".$db_prefix."settings (
+		  `title` VARCHAR(255) NOT NULL DEFAULT 'MGB 0.6.x',
 		  `h_author` VARCHAR(255) NOT NULL, 
 		  `h_domain` VARCHAR(255) NOT NULL, 
 		  `gb_path` VARCHAR(255) NOT NULL, 
@@ -106,11 +121,15 @@
 		  `template_path` VARCHAR(255) NOT NULL DEFAULT 'mgbModern',
 		  `template_style_path` VARCHAR(255) NOT NULL DEFAULT 'blue',
 		  `iconset_path` VARCHAR(255) NOT NULL DEFAULT 'default', 
-		  `language_path` VARCHAR(255) NOT NULL DEFAULT 'lang_german_latin9', 
+		  `language_path` VARCHAR(255) NOT NULL DEFAULT 'lang_german_utf8', 
 		  `badwords` MEDIUMTEXT NOT NULL, 
 		  `bbcode` TINYINT(1) NOT NULL DEFAULT '1', 
 		  `smileys` TINYINT(1) NOT NULL DEFAULT '1', 
 		  `captcha` TINYINT(1) NOT NULL DEFAULT '1', 
+		  `captcha_method` TINYINT(1) NOT NULL DEFAULT '1', 
+		  `akismet_plugin` TINYINT(1) NOT NULL DEFAULT '1', 
+		  `akismet_api` VARCHAR(50) NOT NULL, 
+		  `akismet_mark_as_spam` TINYINT(1) NOT NULL,
 		  `user_notification` TINYINT(1) NOT NULL DEFAULT '1', 
 		  `user_show_email` TINYINT(1) NOT NULL DEFAULT '1', 
 		  `session_timeout` INT(4) NOT NULL DEFAULT '1800', 
@@ -123,11 +142,11 @@
 		  `dateform` VARCHAR(5) NOT NULL DEFAULT 'd/m/Y', 
 		  `gravatar_show` TINYINT(1) NOT NULL DEFAULT '0',
 		  `gravatar_rating` TINYINT(1) NOT NULL DEFAULT '0', 
-		  `version` VARCHAR(20) NOT NULL DEFAULT '0.6',
+		  `version` VARCHAR(20) NOT NULL,
 		  PRIMARY KEY (`title`) 
-		 ) TYPE = MYISAM ;";
+		 ) TYPE = MYISAM;";
 
-	$sql[6] = "INSERT INTO ".$db_prefix."settings (
+	$sql[8] = "INSERT INTO ".$db_prefix."settings (
 		  `title` ,
 		  `h_author` , 
 		  `h_domain` , 
@@ -152,6 +171,10 @@
 		  `bbcode` , 
 		  `smileys` , 
 		  `captcha` , 
+		  `captcha_method` , 
+		  `akismet_plugin` , 
+		  `akismet_api` , 
+		  `akismet_mark_as_spam` , 
 		  `user_notification` , 
 		  `user_show_email` , 
 		  `session_timeout` , 
@@ -190,7 +213,11 @@
 		  '1', 
 		  '1', 
 		  '1', 
-		  '1', 
+		  '0', 
+		  '0', 
+		  '', 
+		  '1',
+		  '1',
 		  '1',
 		  '1800', 
 		  '1', 
@@ -206,7 +233,7 @@
 		  );";
 
 
-	$sql[7] = "CREATE TABLE ".$db_prefix."user (
+	$sql[9] = "CREATE TABLE ".$db_prefix."user (
 		  `ID` INT NOT NULL AUTO_INCREMENT PRIMARY KEY ,
 		  `user_name` VARCHAR( 255 ) NOT NULL ,
 		  `user_password` VARCHAR( 255 ) NOT NULL ,
@@ -219,13 +246,14 @@
 		  `r_deactivate` TINYINT( 1 ) NOT NULL ,
 		  `r_delete` TINYINT( 1 ) NOT NULL ,
 		  `r_edit` TINYINT( 1 ) NOT NULL ,
+		  `r_spam` TINYINT( 1 ) NOT NULL ,
 		  `logged_in` INT( 255 ) NOT NULL ,
 		  `logged_out` TINYINT( 1 ) NOT NULL ,
 		  `np_key` VARCHAR( 16 ) NOT NULL ,
 		  `np_expiration` VARCHAR( 255 ) NOT NULL
-		  ) TYPE = MYISAM ;";
+		  ) TYPE = MYISAM;";
 
-	$sql[8] = "INSERT INTO ".$db_prefix."user ( 
+	$sql[10] = "INSERT INTO ".$db_prefix."user ( 
 		  `ID` ,
 		  `user_name` ,
 		  `user_password` ,
@@ -238,6 +266,7 @@
 		  `r_deactivate` ,
 		  `r_delete` ,
 		  `r_edit`,
+		  `r_spam`,
 		  `logged_in` ,
 		  `logged_out`,
 		  `np_key` ,
@@ -255,6 +284,7 @@
 		  '1',
 		  '1',
 		  '1',
+		  '1',
 		  '".time()."',
 		  '1',
 		  '',
@@ -263,14 +293,18 @@
 
 	if(!isset($success)) { $success = 0; }
 	
-	for($i = 1; $i <= 8; $i++)
+	for($i = 1; $i <= 10; $i++)
 		{
 		$sqlcommand = $sql[$i];
 		$link = @mysql_connect($db_hostname, $db_username, $db_password) or die ("(mysql.php) Error: ".mysql_error());
 		@mysql_select_db($db_dbname, $link) or die ("(mysql.php) Error: ".mysql_error());
-		if(@mysql_query($sqlcommand, $link) == TRUE)
+		if(@mysql_query($sqlcommand, $link) === TRUE)
 			{
 			$success++;
 			}
+		else
+			{
+			echo mysql_error();
+			}
 		}
 ?>
